import { h } from '@stencil/core';
import state from '../../store';
import { hideField } from '../../utils/form';
import { scrollToTop } from '../../utils/scroll';
export class HemfixarnaAddress {
  constructor() {
    this.handleSubmit = (e) => {
      e.preventDefault();
      const streetValid = this.street.length > 0;
      if (!streetValid) {
        this.streetError = 'Ange en gatuadress';
      }
      const zipValid = this.zip.length > 0;
      const zipIsNumber = /^\s*\d[\d\s]*$/.test(this.zip);
      if (!zipIsNumber) {
        this.zipError = 'Postnummer får endast innehålla siffror';
      }
      if (!zipValid) {
        this.zipError = 'Ange ett postnummer';
      }
      const townValid = /^[^\d\s]{2,}$/.test(this.town);
      if (!townValid) {
        this.townError = 'Ange en ort';
      }
      if (streetValid && zipValid && townValid && zipIsNumber) {
        state.user = Object.assign(Object.assign({}, state.user), { street: this.street, zip: this.zip, town: this.town });
        state.checkoutStep = 2;
        state.checkoutEdit = false;
        const el = this.el.closest('.hemfixarna_content');
        scrollToTop(el);
      }
    };
    this.handleChangeStreet = (e) => {
      this.streetError = null;
      this.street = this.street === state.user.street ? '' : e.target.value;
    };
    this.handleChangeZip = (e) => {
      this.zipError = null;
      this.zip = this.zip === state.user.zip ? '' : e.target.value;
    };
    this.handleChangeTown = (e) => {
      this.townError = null;
      this.town = this.town === state.user.town ? '' : e.target.value;
    };
    this.render = () => {
      return (h("form", { class: "hemfixarna_address", onSubmit: e => this.handleSubmit(e) }, h("div", null, h("input", { class: `${this.street.length ? 'input_active' : ''}`, onInput: this.handleChangeStreet, type: "text", name: "street", value: this.street === state.user.street ? hideField(this.street) : this.street }), h("label", { htmlFor: "street" }, "Gatuaddress ")), this.streetError && h("span", null, this.streetError), h("div", null, h("input", { class: `${this.zip.length ? 'input_active' : ''}`, onInput: this.handleChangeZip, type: "tel", name: "zip", value: this.zip === state.user.zip ? hideField(this.zip) : this.zip }), h("label", { htmlFor: "zip" }, "Postnummer ")), this.zipError && h("span", null, this.zipError), h("div", null, h("input", { class: `${this.town.length ? 'input_active' : ''}`, onInput: this.handleChangeTown, type: "text", name: "town", value: this.town === state.user.town ? hideField(this.town) : this.town }), h("label", { htmlFor: "town" }, "Ort ")), this.townError && h("span", null, this.townError), h("input", { type: "submit", value: "Forts\u00E4tt" })));
    };
    this.street = '';
    this.streetError = null;
    this.zip = '';
    this.zipError = null;
    this.town = '';
    this.townError = null;
  }
  componentWillLoad() {
    if (state.user) {
      this.street = state.user.street;
      this.zip = state.user.zip;
      this.town = state.user.town;
    }
  }
  static get is() { return "hemfixarna-address"; }
  static get states() {
    return {
      "street": {},
      "streetError": {},
      "zip": {},
      "zipError": {},
      "town": {},
      "townError": {}
    };
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=hemfixarna-address.js.map
