import { Fragment, getAssetPath, h } from '@stencil/core';
import state from '../../store';
import { Business } from '../../types';
import { postOrder } from '../../utils/api';
import { postPerson } from '../../utils/felixApi';
import { hideField } from '../../utils/form';
import { scrollToTop } from '../../utils/scroll';
export class HemfixarnaCheckout {
  constructor() {
    this.handleChangeDate = (e) => {
      this.dateError = null;
      this.date = e.target.value;
    };
    this.handleChangeTerms = () => {
      this.generalError = null;
    };
    this.sendOrder = async () => {
      var _a, _b, _c, _d;
      if (this.loading)
        return;
      this.loading = true;
      const startFees = state.cart
        .filter(item => item.start_fee_obj)
        .map(item => {
        var _a, _b, _c;
        return ({
          ID: (_a = item.start_fee_obj) === null || _a === void 0 ? void 0 : _a.ID,
          title: (_b = item.start_fee_obj) === null || _b === void 0 ? void 0 : _b.title,
          price: (_c = item.start_fee_obj) === null || _c === void 0 ? void 0 : _c.price,
          rut: item.rut ? 1 : 0,
          rot: item.rot ? 1 : 0,
          green: item.green ? 1 : 0,
        });
      });
      let order = {
        firstName: state.creditSafeUser.firstName,
        lastName: state.creditSafeUser.lastName,
        street: state.user.street,
        zip: state.user.zip,
        town: state.user.town,
        ssn: state.user.ssn,
        email: state.user.email,
        phone: state.user.phone,
        url: `${state.business === Business.string ? 'string' : state.business}-webk`,
        date: this.date,
        products: [
          ...state.cart.map(item => {
            const parts = item.parts.map(part => ({
              id: String(part.id),
              name: part.name,
              quantity: part.amount,
              rut: 0,
              rot: 0,
              start_fee_id: item.start_fee_obj ? item.start_fee_obj.ID : null,
            }));
            return [
              {
                id: String(item.id),
                name: item.name,
                quantity: item.amount,
                rot: item.rot ? 1 : 0,
                rut: item.rut ? 1 : 0,
                start_fee_id: item.start_fee_obj ? item.start_fee_obj.ID : null,
              },
              ...parts,
            ];
          }),
        ].flat(),
        start_fees: startFees,
        creditSafe: state.creditSafeUser,
        customer: state.business,
        id_source: state.customer.source ? state.customer.source.fieldData.So01_Name : '',
        id_sub_source: this.selectedSubSource ? this.selectedSubSource : '',
        seller_id: (_a = this.sellerID) !== null && _a !== void 0 ? _a : '',
        referral_id: (_b = this.RefferalID) !== null && _b !== void 0 ? _b : '',
      };
      const felixOrder = await postPerson(order);
      if (!felixOrder || !((_d = (_c = felixOrder.response) === null || _c === void 0 ? void 0 : _c.scriptResult) === null || _d === void 0 ? void 0 : _d.includes('OK'))) {
        order = Object.assign(Object.assign({}, order), { felixStatus: 'error' });
      }
      else {
        order = Object.assign(Object.assign({}, order), { felixStatus: 'success' });
      }
      try {
        const { data: orderConfirm, status } = await postOrder(order);
        if (orderConfirm && status && status === 200) {
          state.step = 6;
          const el = this.el.closest('.hemfixarna_content');
          scrollToTop(el);
        }
        else {
          this.generalError = 'Något gick fel, försök igen senare';
        }
      }
      catch (error) {
        this.generalError = 'Något gick fel, försök igen senare';
      }
      this.loading = false;
    };
    this.handleSubmit = (e) => {
      var _a;
      e.preventDefault();
      this.generalError = null;
      const validDate = this.date.length > 0;
      if (!validDate) {
        this.dateError = 'Ange ett giltigt datum';
      }
      const checkBoxes = Array.from(this.el.querySelectorAll('input[type="checkbox"]'));
      const notValidTerms = checkBoxes.find(i => !i.checked);
      if (notValidTerms) {
        this.generalError = 'Du måste godkänna villkoren';
      }
      if (state.customer.source && state.selectSource) {
        if (!this.sellerID) {
          this.generalError = 'Ange säljare';
          return;
        }
        if (((_a = state.customer.source.sub_sources) === null || _a === void 0 ? void 0 : _a.length) && !this.selectedSubSource) {
          this.generalError = 'Välj underkälla';
          return;
        }
      }
      if (validDate && !notValidTerms) {
        this.sendOrder();
      }
    };
    this.render = () => {
      var _a;
      const dateLogo = getAssetPath(`./assets/date.svg`);
      const down = getAssetPath(`./assets/down.svg`);
      const loading = getAssetPath(`./assets/spinner.gif`);
      if (state.checkoutEdit) {
        return h("hemfixarna-address", null);
      }
      else if (state.checkoutStep === 1) {
        return h("hemfixarna-getuser", null);
      }
      else if (state.checkoutStep === 2) {
        return (h("div", { class: "mb-2" }, h("div", { class: "hemfixarna_addressinfo" }, h("div", null, h("p", null, hideField(state.user.firstName)), h("p", null, hideField(state.user.lastName)), h("p", null, state.user.email), h("p", null, state.user.phone)), h("div", null, h("p", null, hideField(state.user.street)), h("p", null, hideField(state.user.zip)), h("p", null, hideField(state.user.town))), h("button", { onClick: () => (state.checkoutEdit = true) }, "Beh\u00F6ver du \u00E4ndra adressen?")), h("form", { onSubmit: e => this.handleSubmit(e) }, h("div", null, h("img", { src: dateLogo, width: 24 }), h("input", { class: `${this.date.length ? 'input_active' : ''}`, min: new Date().toISOString().split('T')[0], onChange: e => this.handleChangeDate(e), type: "date", name: "date", value: this.date }), h("label", { htmlFor: "date" }, "Tidigaste datum f\u00F6r hembes\u00F6k"), h("img", { src: down, width: 24 })), this.dateError && h("span", null, this.dateError), state.customer.source && state.selectSource ? (h(Fragment, null, h("p", null, "Inloggad som:", h("strong", null, " ", state.customer.source.fieldData.So01_Name)), h("label", null, "S\u00E4ljare (S\u00E4ljarId)", h("input", { type: "text", value: this.sellerID, onChange: e => (this.sellerID = e.target.value) })), h("label", null, "PartnerOrderID (RefferalID)", h("input", { type: "text", value: this.RefferalID, onChange: e => (this.RefferalID = e.target.value) })), ((_a = state.customer.source.sub_sources) === null || _a === void 0 ? void 0 : _a.length) ? (h("div", null, h("select", { onChange: e => (this.selectedSubSource = e.target.value) }, h("option", { disabled: true, selected: true, value: "null" }, "V\u00E4lj underk\u00E4lla"), state.customer.source.sub_sources.map(sub => (h("option", { value: sub['So_SubSource::Sus01_Name'] }, sub['So_SubSource::Sus01_Name'])))))) : (h("p", null, "Det finns inga underk\u00E4llor att v\u00E4lja")))) : null, h("label", { class: "hemfixarna_checkbox" }, h("input", { onChange: () => this.handleChangeTerms(), type: "checkbox" }), h("span", { innerHTML: state.options.terms })), state.cart
          .filter(i => { var _a; return (_a = i.terms_checkout) === null || _a === void 0 ? void 0 : _a.length; })
          .map(item => (h(Fragment, null, h("label", { class: "hemfixarna_checkbox" }, h("input", { onChange: () => this.handleChangeTerms(), type: "checkbox" }), h("span", null, item.terms_checkout))))), this.generalError && h("span", null, this.generalError), h("div", { class: this.loading ? 'loading' : '' }, h("input", { type: "submit", value: this.loading ? '' : 'Skicka bokning' }), h("img", { width: 20, height: 20, src: loading, alt: "spinner" })))));
      }
    };
    this.date = '';
    this.dateError = null;
    this.generalError = null;
    this.loading = false;
    this.enteredPin = '';
    this.selectedSubSource = null;
    this.partnerOrderId = null;
    this.sellerID = null;
    this.RefferalID = null;
  }
  componentWillLoad() {
    if (Boolean(state.user && state.user.street)) {
      state.checkoutStep = 2;
    }
  }
  static get is() { return "hemfixarna-checkout"; }
  static get states() {
    return {
      "date": {},
      "dateError": {},
      "generalError": {},
      "loading": {},
      "enteredPin": {},
      "selectedSubSource": {},
      "partnerOrderId": {},
      "sellerID": {},
      "RefferalID": {}
    };
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=hemfixarna-checkout.js.map
