import { Fragment, getAssetPath, h } from '@stencil/core';
import state from '../../store';
import { WidgetStyle } from '../../types';
import { getCustomer, getGreenDiscount, getOptions, getRot, getRut, loginCustomer } from '../../utils/api';
import { getProductPriceWithRotAndRut } from '../../utils/calc';
import { scrollToTop } from '../../utils/scroll';
export class HemfixarnaComponent {
  constructor() {
    this.triggerScrollTotop = () => {
      const el = this.el.shadowRoot.querySelector('.hemfixarna_content');
      scrollToTop(el);
    };
    this.modal = false;
    this.showModal = false;
    this.product = null;
    this.id = undefined;
    this.slug = undefined;
    this.business = undefined;
    this.widgetStyle = WidgetStyle.standard;
    this.buttonColor = undefined;
    this.buttonBg = undefined;
    this.proppedProduct = null;
    this.loginSourceError = null;
  }
  loadCategoryOrProduct(id) {
    this.proppedProduct = null;
    if (id.startsWith('c-')) {
      const categories = [...state.customer.categories, ...state.customer.categories.map(c => { var _a; return (_a = c.sub_categories) !== null && _a !== void 0 ? _a : []; })].flat();
      const category = categories.find(c => c && c.id === id.replace('c-', ''));
      if (category) {
        state.selectedCustomerCategory = category;
        state.step = 2;
      }
    }
    else {
      const products = state.customer.categories
        .map(c => (c.show_products ? c.products : c.sub_categories ? c.sub_categories.map(c => c.products) : []))
        .flat()
        .flat();
      const product = products.find(p => p && p.fields.ID === parseInt(id));
      if (product) {
        state.selectedProduct = product.fields;
        state.step = 4;
        this.proppedProduct = product.fields;
      }
    }
  }
  async watchIdChange(id) {
    if (id && state.customer) {
      if (id === 'maleri') {
        state.maleri = true;
        state.step = 4;
      }
      else {
        this.loadCategoryOrProduct(id);
      }
    }
  }
  async componentWillLoad() {
    state.business = this.business;
    const cart = window.sessionStorage.getItem(`hemfixarna-${this.business}-cart`);
    if (cart) {
      state.cart = JSON.parse(cart);
    }
    const user = window.sessionStorage.getItem(`hemfixarna-${this.business}-user`);
    if (user) {
      state.user = JSON.parse(user);
    }
    const creditSafeUser = window.sessionStorage.getItem(`hemfixarna-${this.business}-creditSafeUser`);
    if (creditSafeUser) {
      state.creditSafeUser = JSON.parse(creditSafeUser);
    }
    const [options, rut, rot, greenDiscount] = await Promise.all([getOptions(), getRut(), getRot(), getGreenDiscount()]);
    try {
      const customer = await getCustomer(this.business);
      if ((customer === null || customer === void 0 ? void 0 : customer.code) === 'not_found') {
        console.warn('customer not found');
      }
      else if (customer) {
        state.customer = customer;
        const id = this.id || this.slug;
        if (id) {
          if (id === 'maleri') {
            state.maleri = true;
            state.step = 4;
          }
          else {
            this.loadCategoryOrProduct(id);
          }
        }
      }
    }
    catch (error) {
      console.warn('customer not found');
    }
    state.rotOptions = rot;
    state.rutOptions = rut;
    state.greenOptions = greenDiscount;
    state.options = options;
    if (localStorage.getItem('select_source')) {
      state.selectSource = true;
    }
  }
  // Open close modal && click outside event
  openModal() {
    if (this.id) {
      if (this.id === 'maleri') {
        state.maleri = true;
        state.step = 4;
      }
      else {
        state.maleri = false;
        this.loadCategoryOrProduct(this.id);
      }
    }
    this.modal = true;
    setTimeout(() => {
      this.showModal = true;
    }, 50);
  }
  closeModal() {
    this.showModal = false;
    setTimeout(() => {
      this.modal = false;
    }, 200);
  }
  handleClick(e) {
    if ((e === null || e === void 0 ? void 0 : e.composedPath()[0]).classList.contains('hemfixarna_backdrop')) {
      this.closeModal();
    }
    const infomodal = this.el.shadowRoot.querySelector('.hemfixarna_infomodal');
    if (infomodal) {
      const isClickInside = infomodal.contains(e.composedPath()[0]);
      if (!isClickInside) {
        state.modal = null;
      }
    }
  }
  async handleLogin() {
    this.loginSourceError = null;
    const passwordInput = this.el.shadowRoot.querySelector('input[type="password"]');
    const password = passwordInput.value;
    try {
      const status = await loginCustomer({ id: state.customer.ID, password: password });
      if (status === 200) {
        state.showSourcePasswordPrompt = false;
        state.selectSource = true;
      }
      else {
        this.loginSourceError = 'Fel lösenord';
      }
    }
    catch (error) {
      console.log(error);
      this.loginSourceError = 'Fel lösenord';
    }
  }
  getCartLength() {
    return state.cart.reduce((acc, curr) => acc + curr.amount, 0);
  }
  render() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    const logo = getAssetPath(`./assets/hemfixarna.svg`);
    const pensel = getAssetPath(`./assets/pensel.svg`);
    const monteringLogo = getAssetPath(`./assets/montering.svg`);
    return (h("div", { class: `hemfixarna hemfixarna-${this.business}` }, h("div", { class: `hemfixarna_box hemfixarna_box--${this.widgetStyle}` }, [WidgetStyle.alternative_2, WidgetStyle.alternative_3].includes(this.widgetStyle) ? (h("img", { src: this.id === 'maleri' ? pensel : monteringLogo, alt: "montering logo", width: 32, height: 32 })) : null, h("div", null, h("div", null, h("p", { onClick: () => this.openModal(), class: `pointer ${[WidgetStyle.alternative_2, WidgetStyle.alternative_3].includes(this.widgetStyle) && state.selectedProduct ? 'underline' : ''}` }, this.id === 'maleri' ? (h("span", null, "Ber\u00E4kna fast pris p\u00E5 m\u00E5leri & tapetsering h\u00E4r")) : (h(Fragment, null, !state.selectedCustomerCategory && !this.product && !this.proppedProduct ? (h(Fragment, null, ((_a = state.customer) === null || _a === void 0 ? void 0 : _a.widget_title) ? (h("span", null, state.customer.widget_title)) : (h("span", null, "Montering/Installation - ", h("strong", { class: "underline" }, "se priser h\u00E4r"))))) : (h(Fragment, null, ((_b = this.product) === null || _b === void 0 ? void 0 : _b.title) || ((_c = this.proppedProduct) === null || _c === void 0 ? void 0 : _c.title) || ((_d = state.selectedCustomerCategory) === null || _d === void 0 ? void 0 : _d.widget_title) || (h("span", null, "Montering", h("wbr", null), "/Installation ", (_f = (_e = state.selectedCustomerCategory) === null || _e === void 0 ? void 0 : _e.name) !== null && _f !== void 0 ? _f : 'på plats', " - ", h("strong", { class: "underline" }, "se priser h\u00E4r"))), this.proppedProduct && !((_g = this.product) === null || _g === void 0 ? void 0 : _g.invoice) && !((_h = this.proppedProduct) === null || _h === void 0 ? void 0 : _h.invoice) ? (h("span", null, ' från', " ", h("strong", null, getProductPriceWithRotAndRut(this.proppedProduct || this.product), "kr"))) : null)))))), this.widgetStyle === WidgetStyle.standard ? h("img", { src: logo, width: 104 }) : null, this.widgetStyle === WidgetStyle.alternative ? (h("span", { class: "p-s" }, "Utf\u00F6rs av ", h("strong", null, "Hemfixarna"))) : null), [WidgetStyle.standard, WidgetStyle.alternative].includes(this.widgetStyle) ? (h("button", { onClick: () => this.openModal(), class: "hemfixarna_btn", style: {
        color: ((_j = this.buttonColor) === null || _j === void 0 ? void 0 : _j.startsWith('#')) || !((_k = this.buttonColor) === null || _k === void 0 ? void 0 : _k.length) ? this.buttonColor : `#${this.buttonColor}`,
        backgroundColor: ((_l = this.buttonBg) === null || _l === void 0 ? void 0 : _l.startsWith('#')) || !((_m = this.buttonBg) === null || _m === void 0 ? void 0 : _m.length) ? this.buttonBg : `#${this.buttonBg}`,
      } }, "Best\u00E4ll h\u00E4r", this.getCartLength() > 0 && h("span", null, this.getCartLength()))) : null, WidgetStyle.alternative_2 === this.widgetStyle ? (h("div", { class: "hemfixarna_altbtn" }, h("strong", { class: "p-s" }, "Utf\u00F6rs av"), h("img", { src: logo, alt: "hemfixarna logo", width: 98 }))) : null), this.modal && (h("div", null, h("div", { class: `hemfixarna_modal ${this.showModal ? 'hemfixarna_modal--open' : ''}` }, state.modal && (h("div", { class: "hemfixarna_infomodal" }, state.modal.title && h("h2", null, state.modal.title), h("p", { innerHTML: state.modal.text }), h("div", null, h("button", { onClick: () => (state.modal = null) }, "St\u00E4ng")))), state.showSourcePasswordPrompt ? (h("div", { class: "hemfixarna_source--pw hemfixarna_infomodal" }, h("form", { onSubmit: e => {
        e.preventDefault();
        this.handleLogin();
      } }, h("input", { type: "password", placeholder: "L\u00F6senord" }), h("input", { type: "submit", value: "Logga in" }), this.loginSourceError && h("span", null, "Fel l\u00F6senord")))) : null, state.customer && h("hemfixarna-breadcrumbs", { closeModal: () => this.closeModal() }), h("div", { class: `hemfixarna_content hemfixarna_content--${state.step} ${state.step === 4 && state.maleri ? 'hemfixarna_content--painting' : ''}` }, state.step < 4 && h("hemfixarna-start", null), state.step === 4 && h("hemfixarna-product", null), state.step === 5 && h("hemfixarna-cart", null), state.step === 6 && h("hemfixarna-order", null))), h("div", { class: `hemfixarna_backdrop ${this.showModal ? 'hemfixarna_backdrop--open' : ''}` })))));
  }
  static get is() { return "hemfixarna-component"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["hemfixarna.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["hemfixarna.css"]
    };
  }
  static get assetsDirs() { return ["assets"]; }
  static get properties() {
    return {
      "id": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "id",
        "reflect": false
      },
      "slug": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "slug",
        "reflect": false
      },
      "business": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "Business",
          "resolved": "Business",
          "references": {
            "Business": {
              "location": "import",
              "path": "../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "business",
        "reflect": false
      },
      "widgetStyle": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "WidgetStyle",
          "resolved": "WidgetStyle.alternative | WidgetStyle.alternative_2 | WidgetStyle.alternative_3 | WidgetStyle.standard",
          "references": {
            "WidgetStyle": {
              "location": "import",
              "path": "../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "widget-style",
        "reflect": false,
        "defaultValue": "WidgetStyle.standard"
      },
      "buttonColor": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "button-color",
        "reflect": false
      },
      "buttonBg": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "button-bg",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "modal": {},
      "showModal": {},
      "product": {},
      "proppedProduct": {},
      "loginSourceError": {}
    };
  }
  static get elementRef() { return "el"; }
  static get watchers() {
    return [{
        "propName": "id",
        "methodName": "watchIdChange"
      }];
  }
  static get listeners() {
    return [{
        "name": "click",
        "method": "handleClick",
        "target": undefined,
        "capture": false,
        "passive": false
      }];
  }
}
//# sourceMappingURL=hemfixarna-component.js.map
