import { Fragment, getAssetPath, h } from '@stencil/core';
import { Business, WidgetStyle } from '../../types';
import { getCustomer, loginCustomer } from '../../utils/api';
import { getApiUrl } from '../../utils/enviroment';
import { isBusiness } from '../../utils/types';
export class MyComponent {
  constructor() {
    this.debounce = null;
    this.cdnLink = '<script type="module" src="https://cdn.jsdelivr.net/npm//hemfixarna-web-components@latest/dist/hemfixarna-components/hemfixarna-components.esm.js"></script>';
    this.selectedSlug = undefined;
    this.selectedID = undefined;
    this.tooltipText = 'Kopiera till urklipp';
    this.tree = null;
    this.customer = null;
    this.widgetStyle = WidgetStyle.standard;
    this.buttonBg = '';
    this.buttonColor = '';
    this.partner = undefined;
    this.colorAccessibility = undefined;
    this.loggedIn = false;
    this.loginError = false;
  }
  debouncedFunction() {
    if (this.debounce !== null) {
      clearTimeout(this.debounce);
      this.debounce = null;
    }
    this.debounce = window.setTimeout(() => {
      this.checkColorAccessibility();
      this.debounce = null;
    }, 1500);
  }
  async checkColorAccessibility() {
    const defaultTextColor = '#fff';
    const defaultBgColor = '#c84e18';
    const firstColor = this.buttonBg.length ? (this.buttonBg.startsWith('#') ? this.buttonBg : `#${this.buttonBg}`) : defaultBgColor;
    const secondColor = this.buttonColor.length ? (this.buttonColor.startsWith('#') ? this.buttonColor : `#${this.buttonColor}`) : defaultTextColor;
    try {
      const response = await fetch('https://www.aremycolorsaccessible.com/api/are-they', {
        mode: 'cors',
        method: 'POST',
        body: JSON.stringify({ colors: [firstColor, secondColor] }),
      });
      if (!response) {
        throw new Error('Network response was not ok');
      }
      const json = await response.json();
      if (json && (json)) {
        this.colorAccessibility = json;
      }
    }
    catch (error) {
      console.warn('Error fetching color accessibility:', error);
    }
  }
  getColor(rating) {
    switch (rating) {
      case 'AAA':
        return 'green';
      case 'AA':
        return 'orange';
      case 'A':
        return 'yellow';
      case 'Fail':
        return 'red';
      default:
        return 'black';
    }
  }
  async componentWillLoad() {
    const partner = window.location.pathname.replace('/', '');
    if (!isBusiness(partner) && partner)
      return;
    this.partner = partner ? partner : Business.kund;
    const customer = await getCustomer(this.partner);
    if (customer.code !== 'not_found' && customer) {
      this.customer = customer;
      if (!this.customer.password_protected || window.localStorage.getItem(`${this.customer.ID}-loggedin`)) {
        this.loggedIn = true;
      }
    }
  }
  getExample() {
    return `<hemfixarna-component business="${this.partner}"${this.selectedSlug ? ` slug="${this.selectedSlug}" ` : ''}${this.selectedID ? ` id="${this.selectedID}" ` : ''} ${this.widgetStyle === WidgetStyle.standard ? '' : `widget-style="${this.widgetStyle}"`} ${this.buttonColor.length ? `button-color="${this.buttonColor}"` : ''} ${this.buttonBg.length ? `button-bg="${this.buttonBg}"` : ''}></hemfixarna-component>`;
  }
  copyExample() {
    navigator.clipboard.writeText(this.getExample());
    this.tooltipText = 'Snippet kopierad';
    setTimeout(() => {
      this.tooltipText = 'Kopiera till urklipp';
    }, 2000);
  }
  copyCdn() {
    navigator.clipboard.writeText(this.cdnLink);
    this.tooltipText = 'Text kopierad';
    setTimeout(() => {
      this.tooltipText = 'Kopiera till urklipp';
    }, 2000);
  }
  copyNpmInstall() {
    navigator.clipboard.writeText('npm i hemfixarna-web-components');
    this.tooltipText = 'Text kopierad';
    setTimeout(() => {
      this.tooltipText = 'Kopiera till urklipp';
    }, 2000);
  }
  showMaleri() {
    var _a;
    const allCategories = (_a = this.customer) === null || _a === void 0 ? void 0 : _a.categories.map(c => (c.sub_categories ? c.sub_categories : c)).flat();
    return allCategories === null || allCategories === void 0 ? void 0 : allCategories.some(c => c.add_painting);
  }
  async handleLogin() {
    const shadowHost = document.querySelector('hemfixarna-demo');
    const shadowRoot = shadowHost.shadowRoot;
    const passwordInput = shadowRoot.querySelector('input[type="password"]');
    const password = passwordInput.value;
    this.loginError = false;
    try {
      const status = await loginCustomer({ id: this.customer.ID, password: password });
      if (status === 200) {
        this.loggedIn = true;
        window.localStorage.setItem(`${this.customer.ID}-loggedin`, 'true');
      }
      else {
        this.loginError = true;
      }
    }
    catch (error) {
      console.log(error);
      this.loginError = true;
    }
  }
  render() {
    var _a;
    const copy = getAssetPath(`./assets/copy.png`);
    return this.customer ? (h(Fragment, null, this.loggedIn ? (h("div", { class: ((_a = this.customer) === null || _a === void 0 ? void 0 : _a.at_hemfixarna) ? 'hemfixarna_hosted' : '' }, h("div", { class: "hemfixarna_scripts" }, h("div", { onClick: () => this.copyExample(), class: "hemfixarna_example" }, h("p", null, this.getExample()), h("img", { src: copy, height: 20 }), h("span", { class: "hemfixarna_example--tooltip" }, this.tooltipText)), h("hemfixarna-component", { business: this.partner, buttonBg: this.buttonBg, buttonColor: this.buttonColor, widgetStyle: this.widgetStyle, id: this.selectedID }), h("div", { class: "hemfixarna_install" }, h("div", { onClick: () => this.copyCdn(), class: "hemfixarna_example" }, h("p", null, this.cdnLink), h("span", { class: "hemfixarna_example--tooltip" }, this.tooltipText), h("img", { src: copy, height: 20 }))), h("div", { class: "hemfixarna_widgetstyles" }, h("h5", null, "Widget styles"), h("div", null, Object.values(WidgetStyle).map(style => (h("label", { key: style }, h("input", { type: "radio", value: style, checked: this.widgetStyle === style, onChange: () => (this.widgetStyle = style) }), style)))), h("div", null, h("div", null, h("h5", null, "Button background color"), h("input", { type: "text", value: this.buttonBg, onInput: e => (this.buttonBg = e.target.value) })), h("div", null, h("h5", null, "Button text color"), h("input", { type: "text", value: this.buttonColor, onInput: e => (this.buttonColor = e.target.value) })))), h("span", null, "Write an hexa code no # needed"), this.colorAccessibility ? (h("div", null, h("h5", null, "Tillg\u00E4nglighetsrapport"), h("div", null, h("strong", null, "Liten text:"), h("span", { style: { color: this.getColor(this.colorAccessibility.small) } }, this.colorAccessibility.small), h("br", null), h("strong", null, "Fet text:"), h("span", { style: { color: this.getColor(this.colorAccessibility.bold) } }, this.colorAccessibility.bold), h("br", null), h("strong", null, "Stor text:"), h("span", { style: { color: this.getColor(this.colorAccessibility.large) } }, this.colorAccessibility.large), h("br", null), h("strong", null, "Kontrastf\u00F6rh\u00E5llande:"), " ", this.colorAccessibility.contrast))) : null), h("ul", { class: "hemfixarna_categories" }, h("div", null, this.customer.logo ? (h("div", { style: { width: '100%', display: 'flex', justifyContent: 'center' } }, h("img", { style: { maxWidth: '250px', height: 'auto', margin: '0 auto 2rem' }, src: this.customer.logo.url, alt: this.customer.post_title }))) : null, this.showMaleri() ? (h("li", null, h("div", { class: "hemfixarna_categories--label hemfixarna_categories--label--big" }, h("div", null, h("p", null, "M\u00E5leriverktyget"), h("span", null, "maleri")), h("div", null, h("button", { onClick: () => navigator.clipboard.writeText('maleri') }, "Kopiera ID"), this.customer.at_hemfixarna ? (h("button", { onClick: () => navigator.clipboard.writeText(`${getApiUrl()}/partner/${this.customer.post_name}?id=maleri`) }, "Kopiera URL")) : (h("button", { onClick: () => (this.selectedID = 'maleri') }, "Ladda m\u00E5leri")))))) : null, this.customer.categories.map(c => (h("li", null, h("div", { class: "hemfixarna_categories--label hemfixarna_categories--label--big" }, h("div", null, h("p", null, c.name), h("span", null, `c-${c.id}`)), h("div", null, h("button", { onClick: () => navigator.clipboard.writeText(`c-${c.id}`) }, "Kopiera ID"), this.customer.at_hemfixarna ? (h("button", { onClick: () => navigator.clipboard.writeText(`${getApiUrl()}/partner/${this.customer.post_name}?id=c-${c.id}`) }, "Kopiera URL")) : (h("button", { onClick: () => (this.selectedID = `c-${c.id}`) }, "Ladda kategori")))), c.show_products && c.products ? (h("ul", null, c.products.map(p => (h("li", null, h("div", { class: "hemfixarna_categories--label hemfixarna_product--label" }, h("div", null, h("p", null, p.fields.title), h("span", null, p.fields.ID)), h("div", null, h("button", { onClick: () => navigator.clipboard.writeText(String(p.fields.ID)) }, "Kopiera ID"), this.customer.at_hemfixarna ? (h("button", { onClick: () => navigator.clipboard.writeText(`${getApiUrl()}/partner/${this.customer.post_name}?id=${p.fields.ID}`) }, "Kopiera URL")) : (h("button", { onClick: () => (this.selectedID = String(p.fields.ID)) }, "Ladda produkt"))))))))) : (h("ul", null, c.sub_categories &&
      c.sub_categories.map(sc => (h("li", null, h("div", { class: "hemfixarna_categories--label" }, h("div", null, h("p", null, sc.name), h("span", null, `c-${sc.id}`)), h("div", null, h("button", { onClick: () => navigator.clipboard.writeText(`c-${sc.id}`) }, "Kopiera ID"), this.customer.at_hemfixarna ? (h("button", { onClick: () => navigator.clipboard.writeText(`${getApiUrl()}/partner/${this.customer.post_name}?id=c-${c.id}`) }, "Kopiera URL")) : (h("button", { onClick: () => (this.selectedID = `c-${sc.id}`) }, "Ladda kategori")))), h("ul", null, sc.products.map(p => (h("li", null, h("div", { class: "hemfixarna_categories--label hemfixarna_product--label" }, h("div", null, h("p", null, p.fields.title), h("span", null, p.fields.ID)), h("div", null, h("button", { onClick: () => navigator.clipboard.writeText(String(p.fields.ID)) }, "Kopiera ID"), this.customer.at_hemfixarna ? (h("button", { onClick: () => navigator.clipboard.writeText(`${getApiUrl()}/partner/${this.customer.post_name}?id=${p.fields.ID}`) }, "Kopiera URL")) : (h("button", { onClick: () => (this.selectedID = String(p.fields.ID)) }, "Ladda produkt")))))))))))))))))))) : (h("div", null, h("form", { onSubmit: e => {
        e.preventDefault();
        this.handleLogin();
      }, style: {
        display: 'flex',
        flexDirection: 'column',
        gap: '1rem',
        maxWidth: '300px',
        margin: 'auto',
        padding: '20px',
        border: '1px solid #ccc',
        borderRadius: '5px',
        gridColumn: 'span 2',
      } }, h("input", { type: "password", placeholder: "L\u00F6senord" }), h("button", { type: "submit" }, "Logga in"), this.loginError && h("span", null, "Fel l\u00F6senord")))))) : (h("h1", { style: {
        textAlign: 'center',
        margin: 'auto',
        padding: '20px',
        fontSize: '24px',
        fontWeight: 'bold',
        color: 'red',
      } }, "No customer found"));
  }
  static get is() { return "hemfixarna-demo"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["hemfixarna-demo.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["hemfixarna-demo.css"]
    };
  }
  static get states() {
    return {
      "selectedSlug": {},
      "selectedID": {},
      "tooltipText": {},
      "tree": {},
      "customer": {},
      "widgetStyle": {},
      "buttonBg": {},
      "buttonColor": {},
      "partner": {},
      "colorAccessibility": {},
      "loggedIn": {},
      "loginError": {}
    };
  }
  static get watchers() {
    return [{
        "propName": "buttonBg",
        "methodName": "debouncedFunction"
      }, {
        "propName": "buttonColor",
        "methodName": "debouncedFunction"
      }];
  }
}
//# sourceMappingURL=hemfixarna-demo.js.map
