import { h } from '@stencil/core';
import Personnummer from 'personnummer';
import state from '../../store';
import apiSearch from '../../utils/creditSafe';
import { scrollToTop } from '../../utils/scroll';
export class HemfixarnaGetuser {
  constructor() {
    this.handleChangeEmail = (e) => {
      this.emailError = null;
      this.email = e.target.value;
    };
    this.handleChangePhone = (e) => {
      this.phoneError = null;
      this.phone = e.target.value;
    };
    this.handleChangessn = (e) => {
      this.ssnError = null;
      this.ssn = e.target.value;
    };
    this.handleSubmit = async (e) => {
      e.preventDefault();
      const emailRegex = new RegExp(/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/);
      const validEmail = emailRegex.test(this.email);
      if (!validEmail) {
        this.emailError = 'Ange en giltig e-postadress';
      }
      const validPhone = /^[\d\s()+-]{6,}$/.test(this.phone);
      if (!validPhone) {
        this.phoneError = 'Ange ett giltigt telefonnummer';
      }
      const validssn = Personnummer.valid(this.ssn);
      if (!validssn) {
        this.ssnError = 'Ange ett giltigt personnummer';
      }
      else if (validssn) {
        const pn = Personnummer.parse(this.ssn).format(true);
        this.ssn = [pn.slice(0, 8), '-', pn.slice(8)].join('');
      }
      if (validEmail && validPhone && validssn) {
        try {
          const creditSafeData = await apiSearch(this.ssn);
          if (creditSafeData) {
            state.creditSafeUser = creditSafeData;
            state.checkoutStep = 2;
            state.user = Object.assign(Object.assign({}, creditSafeData), { email: this.email, phone: this.phone, ssn: this.ssn });
          }
          else {
            this.ssnError = 'Vi kunde tyvärr inte hitta en address med ditt angivna personnummer';
          }
        }
        catch (e) {
          this.ssnError = 'Vi kunde tyvärr inte hitta en address med ditt angivna personnummer';
          console.log(e);
        }
        finally {
          const el = this.el.closest('.hemfixarna_content');
          scrollToTop(el);
        }
      }
    };
    this.render = () => {
      return (h("form", { class: "mb-2", onSubmit: e => this.handleSubmit(e) }, h("div", null, h("input", { class: `${this.email.length ? 'input_active' : ''}`, onChange: e => this.handleChangeEmail(e), type: "email", name: "email", value: this.email }), h("label", { htmlFor: "email" }, "E-post ")), this.emailError && h("span", null, this.emailError), h("div", null, h("input", { class: `${this.phone.length ? 'input_active' : ''}`, onChange: e => this.handleChangePhone(e), type: "tel", name: "phone", value: this.phone }), h("label", { htmlFor: "phone" }, "Mobiltelefon ")), this.phoneError && h("span", null, this.phoneError), h("div", null, h("input", { class: `${this.ssn.length ? 'input_active' : ''}`, onChange: e => this.handleChangessn(e), type: "tel", name: "ssn", value: this.ssn }), h("label", { htmlFor: "phone" }, "Personnummer*")), this.ssnError && h("span", null, this.ssnError), h("input", { type: "submit", value: "Forts\u00E4tt*" }), h("p", null, "*Vi h\u00E4mtar din adress")));
    };
    this.email = '';
    this.emailError = null;
    this.phone = '';
    this.phoneError = null;
    this.ssn = '';
    this.ssnError = null;
  }
  componentWillLoad() {
    if (state.user) {
      this.email = state.user.email;
      this.phone = state.user.phone;
      this.ssn = state.user.ssn;
    }
  }
  static get is() { return "hemfixarna-getuser"; }
  static get states() {
    return {
      "email": {},
      "emailError": {},
      "phone": {},
      "phoneError": {},
      "ssn": {},
      "ssnError": {}
    };
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=hemfixarna-getuser.js.map
