import { getAssetPath, h } from '@stencil/core';
import state from '../../store';
import { getApiUrl } from '../../utils/enviroment';
const base = `${getApiUrl()}/wp-json/headless`;
export class HemfixarnaInvoice {
  constructor() {
    this.formError = null;
    this.displayImages = [];
    this.formImages = [];
    this.formState = 'initial';
  }
  isValidEmail(email) {
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
  }
  componentDidRender() {
    const form = this.el.querySelector('form');
    if (form) {
      form.addEventListener('input', () => {
        this.formError = null;
      });
    }
  }
  disconnectedCallback() {
    const form = this.el.querySelector('form');
    if (form) {
      form.removeEventListener('input', () => {
        this.formError = null;
      });
    }
  }
  async submit(e) {
    var _a;
    e.preventDefault();
    this.formState = 'loading';
    this.formError = null;
    const form = e.currentTarget.elements;
    const values = {
      description: form.descriptionInput.value.length ? form.descriptionInput.value : null,
      email: form.emailInput.value.length ? form.emailInput.value : null,
      tel: form.telInput.value.length ? form.telInput.value : null,
      terms: (_a = form.termsInput) === null || _a === void 0 ? void 0 : _a.checked,
    };
    if (!values.description) {
      this.formError = 'Vänligen fyll i formulärtexten';
      this.formState = 'initial';
      return;
    }
    if (!values.email || !this.isValidEmail(values.email)) {
      this.formError = 'Vänligen ange en giltig e-postadress';
      this.formState = 'initial';
      return;
    }
    if (!values.tel) {
      this.formError = 'Vänligen ange ditt telefonnummer';
      this.formState = 'initial';
      return;
    }
    if (state.selectedProduct.terms_show_checkbox && !values.terms) {
      this.formError = 'Vänligen acceptera villkoren';
      this.formState = 'initial';
      return;
    }
    const formData = new FormData();
    formData.append('text', values.description);
    formData.append('email', values.email);
    formData.append('phone', values.tel);
    formData.append('customer', state.business);
    this.formImages.forEach(file => {
      formData.append('images[]', file);
    });
    formData.append('product', JSON.stringify({
      title: state.selectedProduct.title,
      amount: 1,
      has_rut: state.selectedProduct.rut,
      has_rot: state.selectedProduct.rot,
      has_green: state.selectedProduct.green,
      ID: state.selectedProduct.ID,
      parts: [],
    }));
    try {
      const res = await fetch(`${base}/saveinvoiceproduct`, {
        method: 'POST',
        body: formData,
      });
      const { response } = await res.json();
      if (response.code === 200) {
        state.checkoutInvoice = true;
        state.step = 6;
      }
      else {
        this.formError = 'Vi kan inte ta emot din beställning just nu';
        this.formState = 'initial';
      }
    }
    catch (error) {
      this.formError = 'Vi kan inte ta emot din beställning just nu';
      this.formState = 'initial';
    }
  }
  handleImageDrop(e) {
    e.preventDefault();
    const files = e.dataTransfer.files;
    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      if (file.type.startsWith('image/')) {
        const reader = new FileReader();
        reader.onload = () => {
          this.displayImages = [...this.displayImages, reader.result];
          this.formImages = [...this.formImages, file];
        };
        reader.readAsDataURL(file);
      }
    }
  }
  handleFileInputChange(e) {
    e.preventDefault();
    const files = e.target.files;
    for (let i = 0; i < files.length; i++) {
      const file = files[i];
      if (file.type.startsWith('image/')) {
        const reader = new FileReader();
        reader.onload = () => {
          this.displayImages = [...this.displayImages, reader.result];
          this.formImages = [...this.formImages, file];
        };
        reader.readAsDataURL(file);
      }
    }
  }
  handleImageClick() {
    this.el.querySelector('.hemfixarna-file-upload').click();
  }
  preventDragOver(e) {
    e.preventDefault();
  }
  removeImage(index) {
    this.displayImages = this.displayImages.filter((_, i) => i !== index);
    this.formImages = this.formImages.filter((_, i) => i !== index);
  }
  render() {
    var _a;
    const upload = getAssetPath(`./assets/drag-drop.svg`);
    return (h("div", { class: "invoice" }, ((_a = state.selectedProduct) === null || _a === void 0 ? void 0 : _a.invoice_description) ? h("p", null, state.selectedProduct.invoice_description) : null, h("form", { onSubmit: e => this.submit(e) }, h("textarea", { name: "descriptionInput", placeholder: "Beskriv ditt \u00E4rende" }), h("div", { role: "button", "aria-label": "upload image", onDragOver: e => this.preventDragOver(e), onDrop: e => this.handleImageDrop(e), onClick: () => this.handleImageClick() }, h("img", { src: upload, alt: "hemfixarna_logo", width: 24 }), h("div", null, h("p", null, "Bifoga ev bilder"), h("span", null, "(dra bilder hit)")), h("input", { onChange: e => this.handleFileInputChange(e), class: "hemfixarna-file-upload", accept: "image/*", type: "file", multiple: true, name: "fileInput" })), h("div", { class: "invoice-preview" }, this.displayImages.map((img, i) => (h("div", { key: i }, h("img", { src: img, alt: "uploaded image" }), h("button", { onClick: () => this.removeImage(i) }, h("img", { src: getAssetPath(`./assets/close.svg`), alt: "close" })))))), h("input", { placeholder: "E-post", type: "email", name: "emailInput" }), h("input", { placeholder: "Telefonnummer", type: "tel", name: "telInput" }), state.selectedProduct.terms_show_checkbox ? (h("label", null, h("input", { type: "checkbox", name: "termsInput" }), state.selectedProduct.terms)) : null, this.formError ? h("span", null, this.formError) : null, h("input", { type: "submit", value: this.formState === 'loading' ? 'Skickar' : 'Kontakta mig' }))));
  }
  static get is() { return "hemfixarna-invoice"; }
  static get originalStyleUrls() {
    return {
      "$": ["hemfixarna-invoice.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["hemfixarna-invoice.css"]
    };
  }
  static get states() {
    return {
      "formError": {},
      "displayImages": {},
      "formImages": {},
      "formState": {}
    };
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=hemfixarna-invoice.js.map
