import { Fragment, getAssetPath, h } from '@stencil/core';
import state from '../../store';
import { groupCartItemsByStartFee, calculateStartFee, calculateGreenDiscount, calculateRot, calculateRut, getPartPrice, getProductPrice, getTotalPrice } from '../../utils/calc';
export class HemfixarnaOrderrows {
  constructor() {
    this.cart = true;
  }
  goToProduct(id) {
    const products = state.customer.categories
      .map(c => (c.show_products ? c.products : c.sub_categories ? c.sub_categories.map(c => c.products) : []))
      .flat()
      .flat();
    const product = products.find(p => p && p.fields.ID === id);
    if (product) {
      state.selectedProduct = product.fields;
      state.step = 4;
    }
  }
  openModal(title, text) {
    state.modal = {
      title,
      text,
    };
  }
  getDiscountedInfo(item) {
    if (item.rut && state.rut) {
      return ' (efter RUT-avdrag)';
    }
    else if (item.rot && state.rot) {
      return ' (efter ROT-avdrag)';
    }
    else if (item.green && state.green) {
      return ' (efter Grön teknik avdrag)';
    }
    else {
      return '';
    }
  }
  renderStartFees() {
    const startFees = new Set();
    const fees = [];
    state.cart.forEach(item => {
      const startFee = item.start_fee_obj;
      if (startFee && !startFees.has(startFee.ID)) {
        startFees.add(startFee.ID);
        const rotStartFee = item.rot ? calculateStartFee().rot : 0;
        const rutStartFee = item.rut ? calculateStartFee().rut : 0;
        const greenStartFee = item.green ? calculateStartFee().green : 0;
        fees.push({
          id: startFee.ID,
          name: startFee.title,
          price: startFee.price,
          text: startFee.pop_up,
          rot: rotStartFee,
          rut: rutStartFee,
          green: greenStartFee,
        });
      }
    });
    return fees.map(fee => (h("div", { key: fee.id, class: "hemfixarna_cart--startfee" }, h("p", { onClick: () => this.openModal(fee.name, fee.text) }, h("strong", null, fee.name), h("img", { height: 16, src: getAssetPath('./assets/info.svg'), alt: "info monteringsavgift" })), h("p", null, !fee.rut && !fee.rot && !fee.green && h("span", null, fee.price, "kr"), fee.rut > 0 && h("span", null, fee.rut, "kr (RUT)"), fee.rot > 0 && h("span", null, fee.rot, "kr (ROT)"), fee.green > 0 && h("span", null, fee.green, "kr (Gr\u00F6n teknik)")))));
  }
  render() {
    return (h(Fragment, null, h("ul", { class: "hemfixarna_cart--items" }, Object.entries(groupCartItemsByStartFee(state.cart)).map(([startFeeID, items]) => (h("li", { key: startFeeID, class: "hemfixarna_cart--group" }, h("ul", null, items.map(item => {
      var _a;
      return (h("li", { class: "hemfixarna_cart--item", key: item.id }, h("div", null, h("div", null, item.icon && (h("img", { width: 30, src: (_a = item.icon.url) !== null && _a !== void 0 ? _a : item.icon, alt: item.name })), h("p", null, h("strong", null, item.amount, "x "), item.name)), this.cart && (h("button", { onClick: () => this.goToProduct(item.id) }, "\u00C4ndra"))), h("p", null, h("strong", null, getProductPrice(item, item.price, item.amount), "kr"), h("span", null, this.getDiscountedInfo(item))), item.parts.length > 0 && (h("ul", null, item.parts.map(part => (h("li", { key: part.name }, h("p", null, h("strong", null, part.amount, "x "), part.name), h("p", null, h("strong", null, getPartPrice(part, item, part.amount), "kr")))))))));
    })))))), h("div", { class: "hemfixarna_cart--additional" }, this.renderStartFees(), this.cart && state.cart.find((item) => item.rot) && (h("div", { class: "hemfixarna_cart--rutrot" }, h("div", null, h("label", { class: "switch" }, h("input", { checked: state.rot, onChange: () => (state.rot = !state.rot), type: "checkbox" }), h("span", { class: "slider" })), h("p", null, "ROT-avdrag")), h("p", null, "(-", state.rot ? calculateRot() : 0, "kr)"))), this.cart && state.cart.find((item) => item.rut) && (h("div", { class: "hemfixarna_cart--rutrot" }, h("div", null, h("label", { class: "switch" }, h("input", { onChange: () => (state.rut = !state.rut), checked: state.rut, type: "checkbox" }), h("span", { class: "slider" })), h("p", null, "RUT-avdrag")), h("p", null, "(-", state.rut ? calculateRut() : 0, "kr)"))), this.cart && state.cart.find((item) => item.green) && (h("div", { class: "hemfixarna_cart--rutrot" }, h("div", null, h("label", { class: "switch" }, h("input", { onChange: () => (state.green = !state.green), checked: state.green, type: "checkbox" }), h("span", { class: "slider" })), h("p", null, "Gr\u00F6n teknik avdrag")), h("p", null, "(-", state.green ? calculateGreenDiscount() : 0, "kr)")))), h("div", { class: "hemfixarna_cart--price" }, h("h2", null, "Totalbelopp: "), h("h2", null, getTotalPrice(), "kr"))));
  }
  static get is() { return "hemfixarna-orderrows"; }
  static get properties() {
    return {
      "cart": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "cart",
        "reflect": false,
        "defaultValue": "true"
      }
    };
  }
}
//# sourceMappingURL=hemfixarna-orderrows.js.map
