import { Fragment, getAssetPath, h } from '@stencil/core';
import state from '../../store';
import { Business } from '../../types';
import { getPartPrice, getProductPrice } from '../../utils/calc';
import { scrollToTop } from '../../utils/scroll';
export class HemfixarnaProduct {
  constructor() {
    this.amount = 0;
    this.hideDescription = true;
  }
  addProduct() {
    const productInCart = state.cart.find(p => p.id === state.selectedProduct.ID);
    if (productInCart) {
      productInCart.amount++;
      state.cart = [...state.cart];
    }
    else {
      state.cart = [
        ...state.cart,
        {
          id: state.selectedProduct.ID,
          rut: state.selectedProduct.rut,
          rot: state.selectedProduct.rot,
          green: state.selectedProduct.green,
          amount: 1,
          parts: [],
          price: state.selectedProduct.price,
          name: state.selectedProduct.title,
          start_fee: !state.selectedProduct.hide_start_fee,
          terms_checkout: state.selectedProduct.terms_checkout,
          icon: state.selectedProduct.icon,
          start_fee_obj: state.selectedProduct.start_fee_obj,
        },
      ];
    }
  }
  removeProduct() {
    const productInCart = state.cart.find(p => p.id === state.selectedProduct.ID);
    if (productInCart && productInCart.amount > 1) {
      productInCart.amount--;
      state.cart = [...state.cart];
    }
    else {
      state.cart = state.cart.filter(p => p.id !== state.selectedProduct.ID);
    }
  }
  //Handle cart and parts
  addPart(part) {
    var _a;
    const productInCart = state.cart.find(p => p.id === state.selectedProduct.ID);
    if (productInCart) {
      const partInCart = productInCart.parts.find(sp => sp.id === part.ID);
      if (partInCart) {
        partInCart.amount++;
        productInCart.parts = [...productInCart.parts];
      }
      else {
        productInCart.parts = [...productInCart.parts, { id: part.ID, amount: 1, price: part.price, name: (_a = part.title) !== null && _a !== void 0 ? _a : part.title }];
      }
      state.cart = [...state.cart.filter(p => p.id !== productInCart.id), productInCart];
    }
  }
  removePart(part) {
    const productInCart = state.cart.find(p => p.id === state.selectedProduct.ID);
    if (productInCart) {
      const partInCart = productInCart.parts.find(sp => sp.id === part.ID);
      if (partInCart && partInCart.amount > 1) {
        partInCart.amount--;
        productInCart.parts = [...productInCart.parts];
      }
      else {
        productInCart.parts = productInCart.parts.filter(sp => sp.id !== part.ID);
      }
      state.cart = [...state.cart.filter(p => p.id !== productInCart.id), productInCart];
    }
  }
  goToCart() {
    const productInCart = state.cart.find(p => p.id === state.selectedProduct.ID);
    if (productInCart) {
      state.step = 5;
      const el = this.el.closest('.hemfixarna_content');
      scrollToTop(el);
    }
  }
  getAmount() {
    var _a;
    return ((_a = state.cart.find(p => p.id === state.selectedProduct.ID)) === null || _a === void 0 ? void 0 : _a.amount) || 0;
  }
  getPartAmount(partId) {
    var _a;
    const productInCart = state.cart.find(p => p.id === state.selectedProduct.ID);
    return ((_a = productInCart === null || productInCart === void 0 ? void 0 : productInCart.parts.find(sp => sp.id === partId)) === null || _a === void 0 ? void 0 : _a.amount) || 0;
  }
  getTotalPrice() {
    let price = 0;
    const productInCart = state.cart.find(p => p.id === state.selectedProduct.ID);
    if (productInCart) {
      const partsPrice = productInCart.parts.reduce((acc, curr) => {
        const part = state.selectedProduct.parts.find(p => p.ID === curr.id);
        if (part) {
          return acc + part.price * curr.amount;
        }
        return acc;
      }, 0);
      price = state.selectedProduct.price * productInCart.amount + partsPrice;
    }
    else {
      price = state.selectedProduct.price;
    }
    return getProductPrice(state.selectedProduct, price);
  }
  componentDidRender() {
    const linkElem = document.createElement('link');
    linkElem.setAttribute('rel', 'stylesheet');
    linkElem.setAttribute('href', 'https://painting-frontend.vercel.app/static/css/main.css');
    const fonts = document.createElement('link');
    fonts.setAttribute('rel', 'stylesheet');
    fonts.setAttribute('href', 'https://painting-frontend.vercel.app/fonts.css');
    const checkAndInjectCSS = () => {
      const parents = this.el.getElementsByTagName('hemfixare-calculator');
      if (parents.length > 0 && parents[0].shadowRoot !== null) {
        parents[0].shadowRoot.appendChild(linkElem);
        parents[0].shadowRoot.appendChild(fonts);
      }
      else {
        setTimeout(checkAndInjectCSS, 1);
      }
    };
    checkAndInjectCSS();
  }
  render() {
    var _a, _b, _c, _d;
    const checked = getAssetPath(`./assets/checked.svg`);
    const plus = getAssetPath(`./assets/plus.svg`);
    const minus = getAssetPath(`./assets/minus.svg`);
    if (state.maleri) {
      return (h("div", { class: "hemfixarna_painting" }, h("script", { type: "text/javascript", src: ['localhost', 'vercel'].some(v => window.location.href.includes(v))
          ? 'https://painting-dev.vercel.app/static/js/main.js'
          : 'https://painting-frontend.vercel.app/static/js/main.js', defer: true, async: true }), h("hemfixare-calculator", { title: state.options.maleri_title, subtitle: state.options.maleri_text, modal: "true", customer: state.business === Business.string ? 'string' : state.business })));
    }
    return state.selectedProduct ? (h("div", { class: "hemfixarna_product" }, h("div", { class: "hemfixarna_product--top" }, state.selectedProduct.icon && (h("img", { width: 80, src: (_a = state.selectedProduct.icon.url) !== null && _a !== void 0 ? _a : state.selectedProduct.icon, alt: state.selectedProduct.title })), h("div", null, h("h1", null, state.selectedProduct.title), !state.selectedProduct.invoice ? h("h2", null, getProductPrice(state.selectedProduct), " kr/st") : h("h2", null, state.selectedProduct.invoice_price))), h("div", { class: "hemfixarna_product--grid" }, h("div", { class: "hemfixarna_product--left" }, ((_b = state.selectedProduct.list) === null || _b === void 0 ? void 0 : _b.length) && (h("ul", { class: "hemfixarna_features" }, state.selectedProduct.list.map(l => (h("li", { key: l.bullet }, h("img", { src: checked, alt: "checked" }), h("p", null, l.bullet)))))), state.selectedProduct.show_pdf && (h("a", { href: `http://hemfixarna.se/wp-json/felix/generatepdf/${state.selectedProduct.ID}`, target: "_blank", class: "generate-pdf-button" }, "Ladda ner tj\u00E4nstebeskrivning")), state.selectedProduct.description && (h("p", { onClick: () => (this.hideDescription = false), class: `hemfixarna_description ${this.hideDescription ? 'hemfixarna_description--hidden' : ''}`, innerHTML: state.selectedProduct.description }))), h("div", { class: "hemfixarna_product--right" }, state.selectedProduct.invoice ? (h("hemfixarna-invoice", null)) : (h(Fragment, null, h("ul", null, h("li", { class: "hemfixarna_product--item" }, h("div", null, h("p", null, state.selectedProduct.title), h("p", { class: "hemfixarna_product--price" }, getProductPrice(state.selectedProduct), "kr/st")), h("div", { class: "hemfixarna_counter" }, h("img", { class: `${this.getAmount() === 0 ? 'disabled' : ''}`, src: minus, onClick: () => this.removeProduct() }), h("span", null, this.getAmount()), h("img", { src: plus, onClick: () => this.addProduct() }))), ((_c = state.selectedProduct.parts) === null || _c === void 0 ? void 0 : _c.length) &&
      state.selectedProduct.parts.map(p => {
        var _a;
        return (h("li", { class: "hemfixarna_part" }, h("div", null, h("p", null, (_a = p.title) !== null && _a !== void 0 ? _a : p.title), h("p", { class: "hemfixarna_product--price" }, getPartPrice(p, state.selectedProduct), "kr/st")), h("div", { class: "hemfixarna_counter" }, h("img", { class: `${this.getPartAmount(p.ID) === 0 ? 'disabled' : ''}`, src: minus, onClick: () => this.removePart(p) }), h("span", null, this.getPartAmount(p.ID)), h("img", { class: `${this.getAmount() === 0 ? 'disabled' : ''}`, src: plus, onClick: () => this.addPart(p) }))));
      })), h("h4", { class: "hemfixarna_product--total" }, "Totalt ", this.getTotalPrice(), " kr"), h("button", { onClick: () => this.goToCart(), class: `hemfixarna_buy ${this.getAmount() === 0 ? 'disabled' : ''}` }, "Forts\u00E4tt"))), !state.selectedProduct.hide_start_fee && ((_d = state.selectedProduct.start_fee_obj) === null || _d === void 0 ? void 0 : _d.title) && (h("p", { class: "hemfixarna_terms" }, h("strong", null, state.selectedProduct.start_fee_obj.title), h("br", null), h("span", { innerHTML: state.selectedProduct.start_fee_obj.description }))), state.options && h("hemfixarna-info", null))))) : null;
  }
  static get is() { return "hemfixarna-product"; }
  static get originalStyleUrls() {
    return {
      "$": ["hemfixarna-product.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["hemfixarna-product.css"]
    };
  }
  static get states() {
    return {
      "amount": {},
      "hideDescription": {}
    };
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=hemfixarna-product.js.map
